/*
 * Copyright (c) 2015 Samsung Electronics Co., Ltd All Rights Reserved
 *
 * Licensed under the Apache License, Version 2.0 (the License);
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an AS IS BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#include "user_callbacks.h"
#include "main.h"

#include <system_info.h>

void _system_info(void *data, Evas_Object *obj, void *event_info)
{
    char *value = NULL;
    bool value_bool = false;
    int ret;

    // Getting the Device Model Name
    ret = system_info_get_platform_string("http://tizen.org/system/model_name", &value);
    if (ret != SYSTEM_INFO_ERROR_NONE) {
        PRINT_MSG("system_info_get_platform_string error: %d", ret);
        dlog_print(DLOG_ERROR, LOG_TAG, "system_info_get_platform_string error: %d", ret);
    } else {
        PRINT_MSG("Model name: %s", value);
        dlog_print(DLOG_ERROR, LOG_TAG, "Model name: %s", value);
    }

    free(value);                // Release after use

    // Checking Whether a Camera is Provided
    ret = system_info_get_platform_bool("http://tizen.org/feature/camera", &value_bool);
    if (ret != SYSTEM_INFO_ERROR_NONE) {
        PRINT_MSG("system_info_get_platform_bool error: %d", ret);
        dlog_print(DLOG_ERROR, LOG_TAG, "system_info_get_platform_bool error: %d", ret);
    } else {
        PRINT_MSG("Camera: %s", value_bool ? "Supported" : "Not supported");
        dlog_print(DLOG_ERROR, LOG_TAG, "Camera: %s", value_bool ? "Supported" : "Not supported");
    }
}

void create_buttons_in_main_window(appdata_s *ad)
{
    Evas_Object *display = _create_new_cd_display(ad, "System Info", _pop_cb);
    _new_button(ad, display, "Start", _system_info);
}
